This is a very basic (hopefully easily understandeable) program to send the data bits of a DHT11 temperature and humidity sensor through Nucleo UART. It is a simple step-by-step guide to build the program.

Dependencies:   mbed

Revision:
1:c0c5b5860aa8
Parent:
0:e8a1a503d390
Child:
2:4469aa7f4995
--- a/main.cpp	Mon Jan 05 22:31:03 2015 +0000
+++ b/main.cpp	Mon Jan 05 22:48:28 2015 +0000
@@ -1,12 +1,14 @@
 #include "mbed.h"
 
 DigitalOut myled(LED1);
+DigitalIn mybutton(USER_BUTTON);
 
 int main() {
     while(1) {
-        myled = 1; // LED is ON
-        wait(0.2); // 200 ms
-        myled = 0; // LED is OFF
-        wait(1.0); // 1 sec
+        if (mybutton == 0) { // Button is pressed
+            myled = 1; // LED is ON
+        } else {
+            myled = 0; // LED is OFF
+        }
     }
 }